==> hinemos_src-2.4.3.tar.gz: Hinemos_src-2.4.3/Sql/src/com/clustercontrol/sql/action/DeleteSql.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.sql.action;

import java.rmi.AccessException;
import java.rmi.RemoteException;

import javax.ejb.FinderException;
import javax.ejb.RemoveException;
import javax.naming.NamingException;
import javax.transaction.HeuristicMixedException;
import javax.transaction.HeuristicRollbackException;
import javax.transaction.InvalidTransactionException;
import javax.transaction.NotSupportedException;
import javax.transaction.RollbackException;
import javax.transaction.SystemException;

import org.eclipse.jface.dialogs.MessageDialog;
import org.quartz.SchedulerException;

import com.clustercontrol.sql.ejb.session.MonitorSqlController;
import com.clustercontrol.sql.util.EjbConnectionManager;
import com.clustercontrol.util.Messages;

/**
 * SQL監視情報を削除するクライアント側アクションクラス<BR>
 * 
 * @version 2.1.0
 * @since 2.0.0
 */
public class DeleteSql {

    /**
     * SQL監視情報を削除します。
     * 
     * @param monitorId 監視項目ID
     * @param monitorType 監視判定タイプ
     * @return 削除に成功した場合、true
     */
    public boolean delete(String monitorId, int monitorType) {
    	
    	MonitorSqlController sql = EjbConnectionManager.getConnectionManager().getSqlController();

        boolean result = false;
  
    	try {
			result = sql.deleteSql(monitorId, monitorType);
			return result;
		} catch (InvalidTransactionException e) {
		} catch (IllegalStateException e) {
		} catch (RemoteException e) {
			if(e instanceof AccessException){
				// アクセス権なしの場合、エラーダイアログを表示する
	            MessageDialog.openInformation(null, Messages.getString("message"),
	                    Messages.getString("message.accesscontrol.16"));
			}
		} catch (FinderException e) {
		} catch (RemoveException e) {
		} catch (SchedulerException e) {
		} catch (NamingException e) {
		} catch (NotSupportedException e) {
		} catch (HeuristicMixedException e) {
		} catch (HeuristicRollbackException e) {
		} catch (RollbackException e) {
		} catch (SystemException e) {
		}

        return false;
    }
}

==> hinemos_src-3.1.0.tar.gz: Hinemos_src-3.1.0/Sql/src/com/clustercontrol/sql/action/DeleteSql.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.sql.action;

import java.rmi.AccessException;
import java.rmi.RemoteException;

import javax.ejb.CreateException;
import javax.ejb.FinderException;
import javax.ejb.RemoveException;
import javax.jms.JMSException;
import javax.naming.NamingException;
import javax.transaction.HeuristicMixedException;
import javax.transaction.HeuristicRollbackException;
import javax.transaction.InvalidTransactionException;
import javax.transaction.NotSupportedException;
import javax.transaction.RollbackException;
import javax.transaction.SystemException;

import org.eclipse.jface.dialogs.MessageDialog;
import org.quartz.SchedulerException;

import com.clustercontrol.sql.ejb.session.MonitorSqlController;
import com.clustercontrol.sql.util.EjbConnectionManager;
import com.clustercontrol.util.Messages;

/**
 * SQL監視情報を削除するクライアント側アクションクラス<BR>
 * 
 * @version 3.0.0
 * @since 2.0.0
 */
public class DeleteSql {

    /**
     * SQL監視情報を削除します。
     * 
     * @param monitorId 監視項目ID
     * @param monitorType 監視判定タイプ
     * @return 削除に成功した場合、true
     */
    public boolean delete(String monitorId, int monitorType) {
    	
    	MonitorSqlController sql = EjbConnectionManager.getConnectionManager().getSqlController();

        boolean result = false;
  
    	try {
			result = sql.deleteSql(monitorId, monitorType);
			return result;
		} catch (InvalidTransactionException e) {
		} catch (IllegalStateException e) {
		} catch (RemoteException e) {
			if(e instanceof AccessException){
				// アクセス権なしの場合、エラーダイアログを表示する
	            MessageDialog.openInformation(null, Messages.getString("message"),
	                    Messages.getString("message.accesscontrol.16"));
			}
		} catch (FinderException e) {
		} catch (RemoveException e) {
		} catch (SchedulerException e) {
		} catch (NamingException e) {
		} catch (NotSupportedException e) {
		} catch (HeuristicMixedException e) {
		} catch (HeuristicRollbackException e) {
		} catch (RollbackException e) {
		} catch (SystemException e) {
		} catch (CreateException e) {
		
			e.printStackTrace();
		} catch (JMSException e) {
		
			e.printStackTrace();
		}

        return false;
    }
}
